@@ -13,14 +13,13 @@
 #    under the License.
 
 from barbicanclient import client as barbican_client
-from neutron.i18n import _LI, _LW, _LE
-from neutron.plugins.common import constants
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import excutils
+from stevedore import driver as stevedore_driver
 
+from neutron_lbaas._i18n import _LI, _LW, _LE
 from neutron_lbaas.common.cert_manager import cert_manager
-from neutron_lbaas.common import keystone
 
 LOG = logging.getLogger(__name__)
 
@@ -29,6 +28,7 @@ CONF = cfg.CONF
 
 class Cert(cert_manager.Cert):
     """Representation of a Cert based on the Barbican CertificateContainer."""
+
     def __init__(self, cert_container):
         if not isinstance(cert_container,
                           barbican_client.containers.CertificateContainer):
@@ -57,41 +57,20 @@ class Cert(cert_manager.Cert):
             return self._cert_container.private_key_passphrase.payload
 
 
-class BarbicanKeystoneAuth(object):
-    _keystone_session = None
-    _barbican_client = None
-
-    @classmethod
-    def get_barbican_client(cls):
-        """Creates a Barbican client object.
-
-        :return: a Barbican Client object
-        :raises Exception: if the client cannot be created
-        """
-        if not cls._barbican_client:
-            try:
-                cls._keystone_session = keystone.get_session()
-                cls._barbican_client = barbican_client.Client(
-                    session=cls._keystone_session,
-                    region_name=CONF.service_auth.region,
-                    interface=CONF.service_auth.endpoint_type
-                )
-            except Exception:
-                # Barbican (because of Keystone-middleware) sometimes masks
-                #  exceptions strangely -- this will reraise the original
-                #  exception, while also providiung useful feedback in the
-                #  logs for debugging
-                with excutils.save_and_reraise_exception():
-                    LOG.exception(_LE("Error creating Barbican client"))
-        return cls._barbican_client
-
-
 class CertManager(cert_manager.CertManager):
     """Certificate Manager that wraps the Barbican client API."""
-    @staticmethod
-    def store_cert(certificate, private_key, intermediates=None,
-                   private_key_passphrase=None, expiration=None,
-                   name='Octavia TLS Cert', **kwargs):
+
+    def __init__(self):
+        super(CertManager, self).__init__()
+        self.auth = stevedore_driver.DriverManager(
+            namespace='neutron_lbaas.cert_manager.barbican_auth',
+            name=cfg.CONF.certificates.barbican_auth,
+            invoke_on_load=True,
+        ).driver
+
+    def store_cert(self, project_id, certificate, private_key,
+                   intermediates=None, private_key_passphrase=None,
+                   expiration=None, name='LBaaS TLS Cert'):
         """Stores a certificate in the certificate manager.
 
         :param certificate: PEM encoded TLS certificate
@@ -104,7 +83,8 @@ class CertManager(cert_manager.CertManager):
         :returns: the container_ref of the stored cert
         :raises Exception: if certificate storage fails
         """
-        connection = BarbicanKeystoneAuth.get_barbican_client()
+
+        connection = self.auth.get_barbican_client(project_id)
 
         LOG.info(_LI(
             "Storing certificate container '{0}' in Barbican."
@@ -154,7 +134,7 @@ class CertManager(cert_manager.CertManager):
         #  feedback in the logs for debugging
         except Exception:
             for secret in [certificate_secret, private_key_secret,
-                      intermediates_secret, pkp_secret]:
+                           intermediates_secret, pkp_secret]:
                 if secret and secret.secret_ref:
                     old_ref = secret.secret_ref
                     try:
@@ -170,22 +150,20 @@ class CertManager(cert_manager.CertManager):
             with excutils.save_and_reraise_exception():
                 LOG.exception(_LE("Error storing certificate data"))
 
-    @staticmethod
-    def get_cert(cert_ref, service_name='lbaas',
-                 lb_id=None,
-                 check_only=False, **kwargs):
+    def get_cert(self, project_id, cert_ref, resource_ref,
+                 check_only=False, service_name='lbaas'):
         """Retrieves the specified cert and registers as a consumer.
 
         :param cert_ref: the UUID of the cert to retrieve
-        :param service_name: Friendly name for the consuming service
-        :param lb_id: Loadbalancer id for building resource consumer URL
+        :param resource_ref: Full HATEOAS reference to the consuming resource
         :param check_only: Read Certificate data without registering
+        :param service_name: Friendly name for the consuming service
 
-        :return: octavia.certificates.common.Cert representation of the
+        :returns: octavia.certificates.common.Cert representation of the
                  certificate data
         :raises Exception: if certificate retrieval fails
         """
-        connection = BarbicanKeystoneAuth.get_barbican_client()
+        connection = self.auth.get_barbican_client(project_id)
 
         LOG.info(_LI(
             "Loading certificate container {0} from Barbican."
@@ -199,15 +177,15 @@ class CertManager(cert_manager.CertManager):
                 cert_container = connection.containers.register_consumer(
                     container_ref=cert_ref,
                     name=service_name,
-                    url=CertManager._get_service_url(lb_id)
+                    url=resource_ref
                 )
             return Cert(cert_container)
         except Exception:
             with excutils.save_and_reraise_exception():
                 LOG.exception(_LE("Error getting {0}").format(cert_ref))
 
-    @staticmethod
-    def delete_cert(cert_ref, lb_id, service_name='lbaas', **kwargs):
+    def delete_cert(self, project_id, cert_ref, resource_ref,
+                    service_name='lbaas'):
         """Deregister as a consumer for the specified cert.
 
         :param cert_ref: the UUID of the cert to retrieve
@@ -216,7 +194,7 @@ class CertManager(cert_manager.CertManager):
 
         :raises Exception: if deregistration fails
         """
-        connection = BarbicanKeystoneAuth.get_barbican_client()
+        connection = self.auth.get_barbican_client(project_id)
 
         LOG.info(_LI(
             "Deregistering as a consumer of {0} in Barbican."
@@ -225,46 +203,10 @@ class CertManager(cert_manager.CertManager):
             connection.containers.remove_consumer(
                 container_ref=cert_ref,
                 name=service_name,
-                url=CertManager._get_service_url(lb_id)
+                url=resource_ref
             )
         except Exception:
             with excutils.save_and_reraise_exception():
                 LOG.exception(_LE(
                     "Error deregistering as a consumer of {0}"
                 ).format(cert_ref))
-
-    @staticmethod
-    def _actually_delete_cert(cert_ref):
-        """Deletes the specified cert. Very dangerous. Do not recommend.
-
-        :param cert_ref: the UUID of the cert to delete
-        :raises Exception: if certificate deletion fails
-        """
-        connection = BarbicanKeystoneAuth.get_barbican_client()
-
-        LOG.info(_LI(
-            "Recursively deleting certificate container {0} from Barbican."
-        ).format(cert_ref))
-        try:
-            certificate_container = connection.containers.get(cert_ref)
-            certificate_container.certificate.delete()
-            if certificate_container.intermediates:
-                certificate_container.intermediates.delete()
-            if certificate_container.private_key_passphrase:
-                certificate_container.private_key_passphrase.delete()
-            certificate_container.private_key.delete()
-            certificate_container.delete()
-        except Exception:
-            with excutils.save_and_reraise_exception():
-                LOG.exception(_LE(
-                    "Error recursively deleting certificate container {0}"
-                ).format(cert_ref))
-
-    @staticmethod
-    def _get_service_url(lb_id):
-        # Format: <servicename>://<region>/<resource>/<object_id>
-        return "{0}://{1}/{2}/{3}".format(
-            cfg.CONF.service_auth.service_name,
-            cfg.CONF.service_auth.region,
-            constants.LOADBALANCER,
-            lb_id)
