@@ -20,13 +20,18 @@ from neutron import context as ncontext
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_serialization import jsonutils
+from oslo_service import service
 from oslo_utils import excutils
 import requests
 
+from neutron_lbaas._i18n import _
+from neutron_lbaas.common import keystone
 from neutron_lbaas.drivers import driver_base
+from neutron_lbaas.drivers.octavia import octavia_messaging_consumer
+from neutron_lbaas.services.loadbalancer import constants
 
 LOG = logging.getLogger(__name__)
-VERSION = "1.0.0"
+VERSION = "1.0.1"
 
 OPTS = [
     cfg.StrOpt(
@@ -45,12 +50,19 @@ OPTS = [
         default=100,
         help=_('Time to stop polling octavia when a status of an entity does '
                'not change.')
+    ),
+    cfg.BoolOpt(
+        'allocates_vip',
+        default=False,
+        help=_('True if Octavia will be responsible for allocating the VIP.'
+               ' False if neutron-lbaas will allocate it and pass to Octavia.')
     )
 ]
+
 cfg.CONF.register_opts(OPTS, 'octavia')
 
 
-def thread_op(manager, entity, delete=False):
+def thread_op(manager, entity, delete=False, lb_create=False):
     context = ncontext.get_admin_context()
     poll_interval = cfg.CONF.octavia.request_poll_interval
     poll_timeout = cfg.CONF.octavia.request_poll_timeout
@@ -62,7 +74,16 @@ def thread_op(manager, entity, delete=False):
         LOG.debug("Octavia reports load balancer {0} has provisioning status "
                   "of {1}".format(entity.root_loadbalancer.id, prov_status))
         if prov_status == 'ACTIVE' or prov_status == 'DELETED':
-            manager.successful_completion(context, entity, delete=delete)
+            kwargs = {'delete': delete}
+            if manager.driver.allocates_vip and lb_create:
+                kwargs['lb_create'] = lb_create
+                # TODO(blogan): drop fk constraint on vip_port_id to ports
+                # table because the port can't be removed unless the load
+                # balancer has been deleted.  Until then we won't populate the
+                # vip_port_id field.
+                # entity.vip_port_id = octavia_lb.get('vip').get('port_id')
+                entity.vip_address = octavia_lb.get('vip').get('ip_address')
+            manager.successful_completion(context, entity, **kwargs)
             return
         elif prov_status == 'ERROR':
             manager.failed_completion(context, entity)
@@ -80,12 +101,15 @@ def thread_op(manager, entity, delete=False):
 def async_op(func):
     @wraps(func)
     def func_wrapper(*args, **kwargs):
-        d = (func.__name__ == 'delete')
+        d = (func.__name__ == 'delete' or func.__name__ == 'delete_cascade')
+        lb_create = ((func.__name__ == 'create') and
+                     isinstance(args[0], LoadBalancerManager))
         try:
             r = func(*args, **kwargs)
             thread = threading.Thread(target=thread_op,
                                       args=(args[0], args[2]),
-                                      kwargs={'delete': d})
+                                      kwargs={'delete': d,
+                                              'lb_create': lb_create})
             thread.setDaemon(True)
             thread.start()
             return r
@@ -97,14 +121,17 @@ def async_op(func):
 
 class OctaviaRequest(object):
 
-    def __init__(self, base_url):
+    def __init__(self, base_url, auth_session):
         self.base_url = base_url
+        self.auth_session = auth_session
 
     def request(self, method, url, args=None, headers=None):
         if args:
             if not headers:
+                token = self.auth_session.get_token()
                 headers = {
-                    'Content-type': 'application/json'
+                    'Content-type': 'application/json',
+                    'X-Auth-Token': token
                 }
             args = jsonutils.dumps(args)
         LOG.debug("url = %s", '%s%s' % (self.base_url, str(url)))
@@ -136,17 +163,25 @@ class OctaviaDriver(driver_base.LoadBalancerBaseDriver):
 
     def __init__(self, plugin):
         super(OctaviaDriver, self).__init__(plugin)
-
-        self.req = OctaviaRequest(cfg.CONF.octavia.base_url)
+        self.req = OctaviaRequest(cfg.CONF.octavia.base_url,
+                                  keystone.get_session())
 
         self.load_balancer = LoadBalancerManager(self)
         self.listener = ListenerManager(self)
         self.pool = PoolManager(self)
         self.member = MemberManager(self)
         self.health_monitor = HealthMonitorManager(self)
-
+        self.l7policy = L7PolicyManager(self)
+        self.l7rule = L7RuleManager(self)
+        self.octavia_consumer = octavia_messaging_consumer.OctaviaConsumer(
+            self)
+        service.launch(cfg.CONF, self.octavia_consumer)
         LOG.debug("OctaviaDriver: initialized, version=%s", VERSION)
 
+    @property
+    def allocates_vip(self):
+        return self.load_balancer.allocates_vip
+
 
 class LoadBalancerManager(driver_base.BaseLoadBalancerManager):
 
@@ -157,6 +192,17 @@ class LoadBalancerManager(driver_base.BaseLoadBalancerManager):
             s += '/%s' % id
         return s
 
+    @property
+    def allocates_vip(self):
+        return cfg.CONF.octavia.allocates_vip
+
+    @property
+    def deletes_cascade(self):
+        return True
+
+    def create_and_allocate_vip(self, context, lb):
+        self.create(context, lb)
+
     @async_op
     def create(self, context, lb):
         args = {
@@ -164,6 +210,7 @@ class LoadBalancerManager(driver_base.BaseLoadBalancerManager):
             'name': lb.name,
             'description': lb.description,
             'enabled': lb.admin_state_up,
+            'project_id': lb.tenant_id,
             'vip': {
                 'subnet_id': lb.vip_subnet_id,
                 'ip_address': lb.vip_address,
@@ -195,6 +242,10 @@ class LoadBalancerManager(driver_base.BaseLoadBalancerManager):
     def get(self, lb):
         return self.driver.req.get(self._url(lb, lb.id))
 
+    @async_op
+    def delete_cascade(self, context, lb):
+        self.driver.req.delete(self._url(lb, lb.id) + '/delete_cascade')
+
 
 class ListenerManager(driver_base.BaseListenerManager):
 
@@ -217,9 +268,11 @@ class ListenerManager(driver_base.BaseListenerManager):
             'protocol_port': listener.protocol_port,
             'connection_limit': listener.connection_limit,
             'tls_certificate_id': listener.default_tls_container_id,
-            'sni_containers': sni_container_ids,
+            'default_pool_id': listener.default_pool_id,
+            'sni_containers': sni_container_ids
         }
         if create:
+            args['project_id'] = listener.tenant_id
             args['id'] = listener.id
         write_func(url, args)
 
@@ -241,9 +294,8 @@ class PoolManager(driver_base.BasePoolManager):
 
     @staticmethod
     def _url(pool, id=None):
-        s = '/v1/loadbalancers/%s/listeners/%s/pools' % (
-            pool.listener.loadbalancer.id,
-            pool.listener.id)
+        s = '/v1/loadbalancers/%s/pools' % (
+            pool.loadbalancer.id)
         if id:
             s += '/%s' % id
         return s
@@ -255,15 +307,20 @@ class PoolManager(driver_base.BasePoolManager):
             'description': pool.description,
             'enabled': pool.admin_state_up,
             'protocol': pool.protocol,
-            'lb_algorithm': pool.lb_algorithm,
+            'lb_algorithm': pool.lb_algorithm
         }
         if pool.session_persistence:
             args['session_persistence'] = {
                 'type': pool.session_persistence.type,
                 'cookie_name': pool.session_persistence.cookie_name,
             }
+        else:
+            args['session_persistence'] = None
         if create:
+            args['project_id'] = pool.tenant_id
             args['id'] = pool.id
+            if pool.listeners:
+                args['listener_id'] = pool.listeners[0].id
         write_func(url, args)
 
     @async_op
@@ -284,9 +341,8 @@ class MemberManager(driver_base.BaseMemberManager):
 
     @staticmethod
     def _url(member, id=None):
-        s = '/v1/loadbalancers/%s/listeners/%s/pools/%s/members' % (
-            member.pool.listener.loadbalancer.id,
-            member.pool.listener.id,
+        s = '/v1/loadbalancers/%s/pools/%s/members' % (
+            member.pool.loadbalancer.id,
             member.pool.id)
         if id:
             s += '/%s' % id
@@ -301,6 +357,7 @@ class MemberManager(driver_base.BaseMemberManager):
             'protocol_port': member.protocol_port,
             'weight': member.weight,
             'subnet_id': member.subnet_id,
+            'project_id': member.tenant_id
         }
         self.driver.req.post(self._url(member), args)
 
@@ -322,14 +379,13 @@ class HealthMonitorManager(driver_base.BaseHealthMonitorManager):
 
     @staticmethod
     def _url(hm):
-        s = '/v1/loadbalancers/%s/listeners/%s/pools/%s/healthmonitor' % (
-            hm.pool.listener.loadbalancer.id,
-            hm.pool.listener.id,
+        s = '/v1/loadbalancers/%s/pools/%s/healthmonitor' % (
+            hm.pool.loadbalancer.id,
             hm.pool.id)
         return s
 
     @classmethod
-    def _write(cls, write_func, url, hm):
+    def _write(cls, write_func, url, hm, create=True):
         args = {
             'type': hm.type,
             'delay': hm.delay,
@@ -339,9 +395,11 @@ class HealthMonitorManager(driver_base.BaseHealthMonitorManager):
             'http_method': hm.http_method,
             'url_path': hm.url_path,
             'expected_codes': hm.expected_codes,
-            'enabled': hm.admin_state_up,
+            'enabled': hm.admin_state_up
         }
-        write_func(cls._url(hm), args)
+        if create:
+            args['project_id'] = hm.tenant_id
+        write_func(url, args)
 
     @async_op
     def create(self, context, hm):
@@ -349,8 +407,94 @@ class HealthMonitorManager(driver_base.BaseHealthMonitorManager):
 
     @async_op
     def update(self, context, old_hm, hm):
-        self._write(self.driver.req.put, self._url(hm), hm)
+        self._write(self.driver.req.put, self._url(hm), hm, create=False)
 
     @async_op
     def delete(self, context, hm):
         self.driver.req.delete(self._url(hm))
+
+
+class L7PolicyManager(driver_base.BaseL7PolicyManager):
+
+    @staticmethod
+    def _url(l7p, id=None):
+        s = '/v1/loadbalancers/%s/listeners/%s/l7policies' % (
+            l7p.listener.loadbalancer.id,
+            l7p.listener.id)
+        if id:
+            s += '/%s' % id
+        return s
+
+    @classmethod
+    def _write(cls, write_func, url, l7p, create=True):
+        args = {
+            'name': l7p.name,
+            'description': l7p.description,
+            'action': l7p.action,
+            'redirect_pool_id': l7p.redirect_pool_id,
+            'redirect_url': l7p.redirect_url,
+            'position': l7p.position,
+            'enabled': l7p.admin_state_up
+        }
+        if args['action'] == constants.L7_POLICY_ACTION_REJECT:
+            del args['redirect_url']
+            del args['redirect_pool_id']
+        elif args['action'] == constants.L7_POLICY_ACTION_REDIRECT_TO_POOL:
+            del args['redirect_url']
+        elif args['action'] == constants.L7_POLICY_ACTION_REDIRECT_TO_URL:
+            del args['redirect_pool_id']
+        if create:
+            args['id'] = l7p.id
+        write_func(url, args)
+
+    @async_op
+    def create(self, context, l7p):
+        self._write(self.driver.req.post, self._url(l7p), l7p)
+
+    @async_op
+    def update(self, context, old_l7p, l7p):
+        self._write(self.driver.req.put, self._url(l7p, id=l7p.id),
+                    l7p, create=False)
+
+    @async_op
+    def delete(self, context, l7p):
+        self.driver.req.delete(self._url(l7p, id=l7p.id))
+
+
+class L7RuleManager(driver_base.BaseL7RuleManager):
+
+    @staticmethod
+    def _url(l7r, id=None):
+        s = '/v1/loadbalancers/%s/listeners/%s/l7policies/%s/l7rules' % (
+            l7r.policy.listener.loadbalancer.id,
+            l7r.policy.listener.id,
+            l7r.policy.id)
+        if id:
+            s += '/%s' % id
+        return s
+
+    @classmethod
+    def _write(cls, write_func, url, l7r, create=True):
+        args = {
+            'type': l7r.type,
+            'compare_type': l7r.compare_type,
+            'key': l7r.key,
+            'value': l7r.value,
+            'invert': l7r.invert
+        }
+        if create:
+            args['id'] = l7r.id
+        write_func(url, args)
+
+    @async_op
+    def create(self, context, l7r):
+        self._write(self.driver.req.post, self._url(l7r), l7r)
+
+    @async_op
+    def update(self, context, old_l7r, l7r):
+        self._write(self.driver.req.put, self._url(l7r, id=l7r.id),
+                    l7r, create=False)
+
+    @async_op
+    def delete(self, context, l7r):
+        self.driver.req.delete(self._url(l7r, id=l7r.id))
