@@ -77,6 +77,54 @@ SUPPORTED_SP_TYPES = (SESSION_PERSISTENCE_SOURCE_IP,
                       SESSION_PERSISTENCE_HTTP_COOKIE,
                       SESSION_PERSISTENCE_APP_COOKIE)
 
+L7_RULE_TYPE_HOST_NAME = 'HOST_NAME'
+L7_RULE_TYPE_PATH = 'PATH'
+L7_RULE_TYPE_FILE_TYPE = 'FILE_TYPE'
+L7_RULE_TYPE_HEADER = 'HEADER'
+L7_RULE_TYPE_COOKIE = 'COOKIE'
+SUPPORTED_L7_RULE_TYPES = (L7_RULE_TYPE_HOST_NAME,
+                           L7_RULE_TYPE_PATH,
+                           L7_RULE_TYPE_FILE_TYPE,
+                           L7_RULE_TYPE_HEADER,
+                           L7_RULE_TYPE_COOKIE)
+
+L7_RULE_COMPARE_TYPE_REGEX = 'REGEX'
+L7_RULE_COMPARE_TYPE_STARTS_WITH = 'STARTS_WITH'
+L7_RULE_COMPARE_TYPE_ENDS_WITH = 'ENDS_WITH'
+L7_RULE_COMPARE_TYPE_CONTAINS = 'CONTAINS'
+L7_RULE_COMPARE_TYPE_EQUAL_TO = 'EQUAL_TO'
+SUPPORTED_L7_RULE_COMPARE_TYPES = (L7_RULE_COMPARE_TYPE_REGEX,
+                                   L7_RULE_COMPARE_TYPE_STARTS_WITH,
+                                   L7_RULE_COMPARE_TYPE_ENDS_WITH,
+                                   L7_RULE_COMPARE_TYPE_CONTAINS,
+                                   L7_RULE_COMPARE_TYPE_EQUAL_TO)
+
+L7_POLICY_ACTION_REJECT = 'REJECT'
+L7_POLICY_ACTION_REDIRECT_TO_POOL = 'REDIRECT_TO_POOL'
+L7_POLICY_ACTION_REDIRECT_TO_URL = 'REDIRECT_TO_URL'
+SUPPORTED_L7_POLICY_ACTIONS = (L7_POLICY_ACTION_REJECT,
+                               L7_POLICY_ACTION_REDIRECT_TO_POOL,
+                               L7_POLICY_ACTION_REDIRECT_TO_URL)
+
+URL_REGEX = "http[s]?://(?:[a-zA-Z]|[0-9]|[$-_@.&+]|[!*(),]|\
+             (?:%[0-9a-fA-F][0-9a-fA-F]))+"
+
+# See RFCs 2616, 2965, 6265, 7230: Should match characters valid in a
+# http header or cookie name.
+HTTP_HEADER_COOKIE_NAME_REGEX = r'\A[a-zA-Z0-9!#$%&\'*+-.^_`|~]+\Z'
+
+# See RFCs 2616, 2965, 6265: Should match characters valid in a cookie value.
+HTTP_COOKIE_VALUE_REGEX = r'\A[a-zA-Z0-9!#$%&\'()*+-./:<=>?@[\]^_`{|}~]+\Z'
+
+# See RFC 7230: Should match characters valid in a header value.
+HTTP_HEADER_VALUE_REGEX = (r'\A[a-zA-Z0-9'
+                           r'!"#$%&\'()*+,-./:;<=>?@[\]^_`{|}~\\]+\Z')
+
+# Also in RFC 7230: Should match characters valid in a header value
+# when quoted with double quotes.
+HTTP_QUOTED_HEADER_VALUE_REGEX = (r'\A"[a-zA-Z0-9 \t'
+                                  r'!"#$%&\'()*+,-./:;<=>?@[\]^_`{|}~\\]*"\Z')
+
 STATS_ACTIVE_CONNECTIONS = 'active_connections'
 STATS_MAX_CONNECTIONS = 'max_connections'
 STATS_TOTAL_CONNECTIONS = 'total_connections'
@@ -102,13 +150,27 @@ OPERATING_STATUSES = (ONLINE, OFFLINE, DEGRADED, DISABLED, NO_MONITOR)
 NO_CHECK = 'no check'
 
 # LBaaS V2 Agent Constants
-# LBaaS V1 Agent constants live in neutron
 LBAAS_AGENT_SCHEDULER_V2_EXT_ALIAS = 'lbaas_agent_schedulerv2'
 AGENT_TYPE_LOADBALANCERV2 = 'Loadbalancerv2 agent'
 LOADBALANCER_PLUGINV2 = 'n-lbaasv2-plugin'
 LOADBALANCER_AGENTV2 = 'n-lbaasv2_agent'
 
+# LBasS V1 Agent Constants
+LOADBALANCER_PLUGIN = 'n-lbaas-plugin'
+LOADBALANCER_AGENT = 'n-lbaas_agent'
+
+LOADBALANCER = "LOADBALANCER"
+LOADBALANCERV2 = "LOADBALANCERV2"
+
 # Used to check number of connections per second allowed
 # for the LBaaS V1 vip and LBaaS V2 listeners. -1 indicates
 # no limit, the value cannot be less than -1.
 MIN_CONNECT_VALUE = -1
+
+# LBaas V2 Table entities
+LISTENER_EVENT = 'listener'
+LISTENER_STATS_EVENT = 'listener_stats'
+LOADBALANCER_EVENT = 'loadbalancer'
+MEMBER_EVENT = 'member'
+OPERATING_STATUS = 'operating_status'
+POOL_EVENT = 'pool'
