@@ -19,15 +19,14 @@ import socket
 import netaddr
 from neutron.agent.linux import ip_lib
 from neutron.agent.linux import utils
-from neutron.common import exceptions
 from neutron.common import utils as n_utils
-from neutron.i18n import _LE, _LW
 from neutron.plugins.common import constants
+from neutron_lib import exceptions
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import excutils
-from oslo_utils import importutils
 
+from neutron_lbaas._i18n import _, _LE, _LW
 from neutron_lbaas.services.loadbalancer.agent import agent_device_driver
 from neutron_lbaas.services.loadbalancer import constants as lb_const
 from neutron_lbaas.services.loadbalancer.drivers.haproxy import cfg as hacfg
@@ -68,14 +67,16 @@ class HaproxyNSDriver(agent_device_driver.AgentDeviceDriver):
         self.conf = conf
         self.state_path = conf.haproxy.loadbalancer_state_path
         try:
-            vif_driver = importutils.import_object(conf.interface_driver, conf)
+            vif_driver_class = n_utils.load_class_by_alias_or_classname(
+                'neutron.interface_drivers',
+                conf.interface_driver)
         except ImportError:
             with excutils.save_and_reraise_exception():
                 msg = (_('Error importing interface driver: %s')
                        % conf.interface_driver)
                 LOG.error(msg)
 
-        self.vif_driver = vif_driver
+        self.vif_driver = vif_driver_class(conf)
         self.plugin_rpc = plugin_rpc
         self.pool_to_port_id = {}
 
@@ -174,7 +175,7 @@ class HaproxyNSDriver(agent_device_driver.AgentDeviceDriver):
             pool_stats['members'] = self._get_servers_stats(parsed_stats)
             return pool_stats
         else:
-            LOG.warn(_LW('Stats socket not found for pool %s'), pool_id)
+            LOG.warning(_LW('Stats socket not found for pool %s'), pool_id)
             return {}
 
     def _get_backend_stats(self, parsed_stats):
@@ -216,7 +217,7 @@ class HaproxyNSDriver(agent_device_driver.AgentDeviceDriver):
 
             return self._parse_stats(raw_stats)
         except socket.error as e:
-            LOG.warn(_LW('Error while connecting to stats socket: %s'), e)
+            LOG.warning(_LW('Error while connecting to stats socket: %s'), e)
             return {}
 
     def _parse_stats(self, raw_stats):
@@ -324,7 +325,7 @@ class HaproxyNSDriver(agent_device_driver.AgentDeviceDriver):
     def deploy_instance(self, logical_config):
         """Deploys loadbalancer if necessary
 
-        :return: True if loadbalancer was deployed, False otherwise
+        :returns: True if loadbalancer was deployed, False otherwise
         """
         # do actual deploy only if vip and pool are configured and active
         if not logical_config or not self._is_active(logical_config):
