@@ -803,6 +803,12 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2):
         return self.db.get_listener(context, id).to_api_dict()
 
     def delete_listener(self, context, id):
+        old_listener = self.db.get_listener(context, id)
+        if old_listener.l7_policies:
+            raise loadbalancerv2.EntityInUse(
+                entity_using=models.L7Policy.NAME,
+                id=old_listener.l7_policies[0].id,
+                entity_in_use=models.Listener.NAME)
         self.db.test_and_set_status(context, models.Listener, id,
                                     constants.PENDING_DELETE)
         listener_db = self.db.get_listener(context, id)
@@ -893,6 +899,12 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2):
         return self.db.get_pool(context, id).to_api_dict()
 
     def delete_pool(self, context, id):
+        old_lb = self.db.get_pool(context, id)
+        if old_lb.healthmonitor:
+            raise loadbalancerv2.EntityInUse(
+                entity_using=models.HealthMonitorV2.NAME,
+                id=old_lb.healthmonitor.id,
+                entity_in_use=models.PoolV2.NAME)
         self.db.test_and_set_status(context, models.PoolV2, id,
                                     constants.PENDING_DELETE)
         db_pool = self.db.get_pool(context, id)
