@@ -8,28 +8,10 @@ SCRIPTS_DIR="/usr/os-testr-env/bin"
 OCTAVIA_DIR="$BASE/new/octavia"
 
 # Sort out our gate args
-. `dirname "$0"`/decode_args.sh
+. $(dirname "$0")/decode_args.sh
 
-LBAAS_VERSION=$lbaasversion
-LBAAS_TEST=$lbaasenv
-LBAAS_DRIVER=$lbaasdriver
-
-if [ "$LBAAS_VERSION" = "lbaasv1" ]; then
-    testenv="apiv1"
-else
-    testenv="apiv2"
-    case "$LBAAS_TEST" in
-        api)
-            if [ "$LBAAS_DRIVER" = "namespace" ]; then
-                test_subset="load_balancers "
-                test_subset+="listeners "
-                test_subset+="pools "
-                test_subset+="members "
-                test_subset+="health_monitor"
-            else
-                testenv=${LBAAS_TEST:-"apiv2"}
-            fi
-            ;;
+if [ "$testenv" = "apiv2" ]; then
+    case "$lbaasenv" in
         minimal)
             # Temporarily just do the happy path
             test_subset="neutron_lbaas.tests.tempest.v2.api.test_load_balancers_non_admin.LoadBalancersTestJSON.test_create_load_balancer(?!_) "
@@ -58,16 +40,13 @@ else
         scenario)
             testenv="scenario"
             ;;
-        *)
-            testenv=${LBAAS_TEST:-"apiv2"}
-            ;;
     esac
 fi
 
 function generate_testr_results {
     # Give job user rights to access tox logs
-    sudo -H -u $owner chmod o+rw .
-    sudo -H -u $owner chmod o+rw -R .testrepository
+    sudo -H -u "$owner" chmod o+rw .
+    sudo -H -u "$owner" chmod o+rw -R .testrepository
     if [ -f ".testrepository/0" ] ; then
         subunit-1to2 < .testrepository/0 > ./testrepository.subunit
         $SCRIPTS_DIR/subunit2html ./testrepository.subunit testr_results.html
@@ -78,28 +57,14 @@ function generate_testr_results {
 }
 
 owner=tempest
+# Configure the api and scenario tests to use the tempest.conf set by devstack
+sudo_env="TEMPEST_CONFIG_DIR=$TEMPEST_CONFIG_DIR"
 
 # Set owner permissions according to job's requirements.
-cd $NEUTRON_LBAAS_DIR
-sudo chown -R $owner:stack $NEUTRON_LBAAS_DIR
+cd "$NEUTRON_LBAAS_DIR"
+sudo chown -R $owner:stack "$NEUTRON_LBAAS_DIR"
 if [ "$lbaasdriver" = "octavia" ]; then
-    sudo chown -R $owner:stack $OCTAVIA_DIR
-fi
-
-sudo_env=" OS_TESTR_CONCURRENCY=1"
-
-# Configure the api and scenario tests to use the tempest.conf set by devstack
-sudo_env+=" TEMPEST_CONFIG_DIR=$TEMPEST_CONFIG_DIR"
-
-if [ "$testenv" = "apiv2" ]; then
-    sudo_env+=" OS_TEST_PATH=$NEUTRON_LBAAS_DIR/neutron_lbaas/tests/tempest/v2/api"
-elif [ "$testenv" = "apiv1" ]; then
-    sudo_env+=" OS_TEST_PATH=$NEUTRON_LBAAS_DIR/neutron_lbaas/tests/tempest/v1/api"
-elif [ "$testenv" = "scenario" ]; then
-    sudo_env+=" OS_TEST_PATH=$NEUTRON_LBAAS_DIR/neutron_lbaas/tests/tempest/v2/scenario"
-else
-    echo "ERROR: unsupported testenv: $testenv"
-    exit 1
+    sudo chown -R $owner:stack "$OCTAVIA_DIR"
 fi
 
 # Run tests
@@ -107,8 +72,6 @@ echo "Running neutron lbaas $testenv test suite"
 set +e
 
 sudo -H -u $owner $sudo_env tox -e $testenv -- $test_subset
-# sudo -H -u $owner $sudo_env testr init
-# sudo -H -u $owner $sudo_env testr run
 
 testr_exit_code=$?
 set -e
