@@ -1,4 +1,6 @@
 # Copyright 2015 Hewlett-Packard Development Company, L.P.
+# Copyright 2016 Rackspace Inc.
+# All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -12,19 +14,16 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from oslo_log import log as logging
 from oslo_utils import uuidutils
-from tempest_lib import exceptions as ex
+from tempest import config
+from tempest.lib.common.utils import data_utils
+from tempest.lib import exceptions as ex
+from tempest import test
 
-from neutron_lbaas.tests.tempest.lib.common.utils import data_utils
-from neutron_lbaas.tests.tempest.lib import config
-from neutron_lbaas.tests.tempest.lib import test
 from neutron_lbaas.tests.tempest.v2.api import base
 
 CONF = config.CONF
 
-LOG = logging.getLogger(__name__)
-
 
 class TestHealthMonitors(base.BaseAdminTestCase):
 
@@ -75,14 +74,11 @@ class TestHealthMonitors(base.BaseAdminTestCase):
         hm_tenant_id = hm.get('tenant_id')
         self.assertEqual(admin_tenant_id, hm_tenant_id)
 
-        # cleanup test
-        self._delete_health_monitor(hm.get('id'))
-
-    @test.attr(type='smoke')
+    @test.attr(type='negative')
     def test_create_health_monitor_empty_tenant_id_field(self):
         """
-        Test with admin user create health monitor with an empty tenant id
-        should fail.
+        Test with admin user creating health monitor with an empty tenant id
+        field should fail.
         """
         self.assertRaises(ex.BadRequest, self._create_health_monitor,
                           type='HTTP', delay=3, max_retries=10,
@@ -104,5 +100,3 @@ class TestHealthMonitors(base.BaseAdminTestCase):
         self.assertEqual(hm.get('tenant_id'), tenantid)
         self.assertNotEqual(hm.get('tenant_id'),
                             self.subnet.get('tenant_id'))
-        # cleanup test
-        self._delete_health_monitor(hm.get('id'))
