@@ -1,4 +1,4 @@
-# Copyright 2015 Rackspace US Inc.
+# Copyright 2015, 2016 Rackspace US Inc.
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -14,19 +14,15 @@
 #    under the License.
 
 from netaddr import IPAddress
+from tempest import config
+from tempest.lib.common.utils import data_utils
+from tempest.lib import exceptions as ex
+from tempest import test
 
-from oslo_log import log as logging
-from tempest_lib.common.utils import data_utils
-from tempest_lib import exceptions
-
-from neutron_lbaas.tests.tempest.lib import config
-from neutron_lbaas.tests.tempest.lib import test
 from neutron_lbaas.tests.tempest.v2.api import base
 
 CONF = config.CONF
 
-LOG = logging.getLogger(__name__)
-
 
 class LoadBalancersTestJSON(base.BaseTestCase):
 
@@ -69,12 +65,12 @@ class LoadBalancersTestJSON(base.BaseTestCase):
         new_load_balancer = self._create_active_load_balancer(
             **self.create_lb_kwargs)
         new_load_balancer_id = new_load_balancer['id']
+        self.addCleanup(self._delete_load_balancer, new_load_balancer_id)
         load_balancers = self.load_balancers_client.list_load_balancers()
         self.assertEqual(len(load_balancers), 2)
         self.assertIn(self.load_balancer, load_balancers)
         self.assertIn(new_load_balancer, load_balancers)
         self.assertNotEqual(self.load_balancer, new_load_balancer)
-        self._delete_load_balancer(new_load_balancer_id)
 
     @test.attr(type='smoke')
     def test_get_load_balancer(self):
@@ -89,11 +85,11 @@ class LoadBalancersTestJSON(base.BaseTestCase):
         new_load_balancer = self._create_active_load_balancer(
             **self.create_lb_kwargs)
         new_load_balancer_id = new_load_balancer['id']
+        self.addCleanup(self._delete_load_balancer, new_load_balancer_id)
         load_balancer = self.load_balancers_client.get_load_balancer(
             new_load_balancer_id)
         self.assertEqual(new_load_balancer, load_balancer)
         self.assertNotEqual(self.load_balancer, new_load_balancer)
-        self._delete_load_balancer(new_load_balancer_id)
 
     @test.attr(type='negative')
     def test_create_load_balancer_missing_vip_subnet_id_field(self):
@@ -101,7 +97,7 @@ class LoadBalancersTestJSON(base.BaseTestCase):
         Test create load balancer with a missing
         required vip_subnet_id field
         """
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self.load_balancers_client.create_load_balancer,
                           wait=False,
                           tenant_id=self.subnet['tenant_id'])
@@ -109,7 +105,7 @@ class LoadBalancersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_create_load_balancer_empty_provider_field(self):
         """Test create load balancer with an empty provider field"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self.load_balancers_client.create_load_balancer,
                           wait=False,
                           provider="")
@@ -119,13 +115,13 @@ class LoadBalancersTestJSON(base.BaseTestCase):
         """Test create load balancer with an empty description field"""
         load_balancer = self._create_active_load_balancer(
             vip_subnet_id=self.subnet['id'], description="")
+        self.addCleanup(self._delete_load_balancer, load_balancer['id'])
         self.assertEqual(load_balancer.get('description'), "")
-        self._delete_load_balancer(load_balancer['id'])
 
     @test.attr(type='negative')
     def test_create_load_balancer_empty_vip_address_field(self):
         """Test create load balancer with empty vip_address field"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self.load_balancers_client.create_load_balancer,
                           wait=False,
                           vip_subnet_id=self.subnet['id'],
@@ -136,13 +132,13 @@ class LoadBalancersTestJSON(base.BaseTestCase):
         """Test create load balancer with a missing admin_state_up field"""
         load_balancer = self._create_active_load_balancer(
             vip_subnet_id=self.subnet['id'])
+        self.addCleanup(self._delete_load_balancer, load_balancer['id'])
         self.assertEqual(load_balancer.get('admin_state_up'), True)
-        self._delete_load_balancer(load_balancer['id'])
 
     @test.attr(type='negative')
     def test_create_load_balancer_empty_admin_state_up_field(self):
         """Test create load balancer with empty admin_state_up field"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self.load_balancers_client.create_load_balancer,
                           wait=False,
                           vip_subnet_id=self.subnet['id'],
@@ -153,27 +149,27 @@ class LoadBalancersTestJSON(base.BaseTestCase):
         """Test create load balancer with a missing name field"""
         load_balancer = self.load_balancers_client.create_load_balancer(
             vip_subnet_id=self.subnet['id'])
+        self.addCleanup(self._delete_load_balancer, load_balancer['id'])
         self.assertEqual(load_balancer.get('name'), '')
         self._wait_for_load_balancer_status(load_balancer['id'])
-        self._delete_load_balancer(load_balancer['id'])
 
     @test.attr(type='smoke')
     def test_create_load_balancer_empty_name(self):
         """Test create load balancer with an empty name field"""
         load_balancer = self.load_balancers_client.create_load_balancer(
             vip_subnet_id=self.subnet['id'], name="")
+        self.addCleanup(self._delete_load_balancer, load_balancer['id'])
         self.assertEqual(load_balancer.get('name'), "")
         self._wait_for_load_balancer_status(load_balancer['id'])
-        self._delete_load_balancer(load_balancer['id'])
 
     @test.attr(type='smoke')
     def test_create_load_balancer_missing_description(self):
         """Test create load balancer with a missing description field"""
         load_balancer = self.load_balancers_client.create_load_balancer(
             vip_subnet_id=self.subnet['id'])
+        self.addCleanup(self._delete_load_balancer, load_balancer['id'])
         self.assertEqual(load_balancer.get('description'), '')
         self._wait_for_load_balancer_status(load_balancer['id'])
-        self._delete_load_balancer(load_balancer['id'])
 
     @test.attr(type='smoke')
     def test_create_load_balancer_missing_vip_address(self):
@@ -183,6 +179,7 @@ class LoadBalancersTestJSON(base.BaseTestCase):
         """
         load_balancer = self._create_active_load_balancer(
             vip_subnet_id=self.subnet['id'])
+        self.addCleanup(self._delete_load_balancer, load_balancer['id'])
         load_balancer_ip_initial = load_balancer['vip_address']
         ip = IPAddress(load_balancer_ip_initial)
         self.assertEqual(ip.version, 4)
@@ -190,24 +187,23 @@ class LoadBalancersTestJSON(base.BaseTestCase):
             load_balancer['id'])
         load_balancer_final = load_balancer['vip_address']
         self.assertEqual(load_balancer_ip_initial, load_balancer_final)
-        self._delete_load_balancer(load_balancer['id'])
 
     @test.attr(type='smoke')
     def test_create_load_balancer_missing_provider_field(self):
         """Test create load balancer with a missing provider field"""
         load_balancer = self._create_active_load_balancer(
             vip_subnet_id=self.subnet['id'])
+        self.addCleanup(self._delete_load_balancer, load_balancer['id'])
         load_balancer_initial = load_balancer['provider']
         load_balancer = self.load_balancers_client.get_load_balancer(
             load_balancer['id'])
         load_balancer_final = load_balancer['provider']
         self.assertEqual(load_balancer_initial, load_balancer_final)
-        self._delete_load_balancer(load_balancer['id'])
 
     @test.attr(type='negative')
     def test_create_load_balancer_invalid_vip_subnet_id(self):
         """Test create load balancer with an invalid vip subnet id"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self.load_balancers_client.create_load_balancer,
                           wait=False,
                           vip_subnet_id="abc123")
@@ -215,7 +211,7 @@ class LoadBalancersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_create_load_balancer_empty_vip_subnet_id(self):
         """Test create load balancer with an empty vip subnet id"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self.load_balancers_client.create_load_balancer,
                           wait=False,
                           vip_subnet_id="")
@@ -223,7 +219,7 @@ class LoadBalancersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_create_load_balancer_invalid_tenant_id(self):
         """Test create load balancer with an invalid tenant id"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self.load_balancers_client.create_load_balancer,
                           wait=False,
                           tenant_id="&^%123")
@@ -231,7 +227,7 @@ class LoadBalancersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_create_load_balancer_invalid_name(self):
         """Test create load balancer with an invalid name"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self.load_balancers_client.create_load_balancer,
                           wait=False,
                           tenant_id=self.subnet['tenant_id'],
@@ -241,7 +237,7 @@ class LoadBalancersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_create_load_balancer_invalid_description(self):
         """Test create load balancer with an invalid description"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self.load_balancers_client.create_load_balancer,
                           wait=False,
                           tenant_id=self.subnet['tenant_id'],
@@ -251,7 +247,7 @@ class LoadBalancersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_create_load_balancer_incorrect_attribute(self):
         """Test create a load balancer with an extra, incorrect field"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self.load_balancers_client.create_load_balancer,
                           wait=False,
                           tenant_id=self.subnet['tenant_id'],
@@ -263,15 +259,15 @@ class LoadBalancersTestJSON(base.BaseTestCase):
         """Test create load balancer with a missing tenant id field"""
         load_balancer = self.load_balancers_client.create_load_balancer(
             vip_subnet_id=self.subnet['id'])
+        self.addCleanup(self._delete_load_balancer, load_balancer['id'])
         self.assertEqual(load_balancer.get('tenant_id'),
                          self.subnet['tenant_id'])
         self._wait_for_load_balancer_status(load_balancer['id'])
-        self._delete_load_balancer(load_balancer['id'])
 
     @test.attr(type='negative')
     def test_create_load_balancer_empty_tenant_id_field(self):
         """Test create load balancer with empty tenant_id field"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self.load_balancers_client.create_load_balancer,
                           vip_subnet_id=self.subnet['id'],
                           wait=False,
@@ -281,12 +277,29 @@ class LoadBalancersTestJSON(base.BaseTestCase):
     def test_create_load_balancer_other_tenant_id_field(self):
         """Test create load balancer for other tenant"""
         tenant = 'deffb4d7c0584e89a8ec99551565713c'
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self.load_balancers_client.create_load_balancer,
                           wait=False,
                           vip_subnet_id=self.subnet['id'],
                           tenant_id=tenant)
 
+    @test.attr(type='negative')
+    def test_create_load_balancer_invalid_flavor_field(self):
+        """Test create load balancer with an invalid flavor field"""
+        self.assertRaises(ex.NotFound,
+                          self.load_balancers_client.create_load_balancer,
+                          vip_subnet_id=self.subnet['id'],
+                          flavor_id="NO_SUCH_FLAVOR")
+
+    @test.attr(type='negative')
+    def test_create_load_balancer_provider_flavor_conflict(self):
+        """Test create load balancer with both a provider and a flavor"""
+        self.assertRaises(ex.Conflict,
+                          self.load_balancers_client.create_load_balancer,
+                          vip_subnet_id=self.subnet['id'],
+                          flavor_id="NO_SUCH_FLAVOR",
+                          provider="NO_SUCH_PROVIDER")
+
     @test.attr(type='smoke')
     def test_update_load_balancer(self):
         """Test update load balancer"""
@@ -308,7 +321,7 @@ class LoadBalancersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_update_load_balancer_invalid_name(self):
         """Test update load balancer with invalid name"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._update_load_balancer,
                           load_balancer_id=self.load_balancer_id,
                           wait=False,
@@ -329,7 +342,7 @@ class LoadBalancersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_update_load_balancer_invalid_description(self):
         """Test update load balancer with invalid description"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._update_load_balancer,
                           load_balancer_id=self.load_balancer_id,
                           wait=False,
@@ -359,7 +372,7 @@ class LoadBalancersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_update_load_balancer_invalid_admin_state_up_field(self):
         """Test update load balancer with an invalid admin_state_up"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._update_load_balancer,
                           load_balancer_id=self.load_balancer_id,
                           wait=False,
@@ -368,7 +381,7 @@ class LoadBalancersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_update_load_balancer_empty_admin_state_up_field(self):
         """Test update load balancer with an empty admin_state_up"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._update_load_balancer,
                           load_balancer_id=self.load_balancer_id,
                           wait=False,
@@ -386,7 +399,7 @@ class LoadBalancersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_update_load_balancer_incorrect_attribute(self):
         """Test update a load balancer with an extra, invalid attribute"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._update_load_balancer,
                           load_balancer_id=self.load_balancer_id,
                           wait=False,
@@ -426,6 +439,6 @@ class LoadBalancersTestJSON(base.BaseTestCase):
         self.assertEqual(new_load_balancer, load_balancer)
         self.assertNotEqual(self.load_balancer, new_load_balancer)
         self._delete_load_balancer(new_load_balancer_id)
-        self.assertRaises(exceptions.NotFound,
+        self.assertRaises(ex.NotFound,
                           self.load_balancers_client.get_load_balancer,
                           new_load_balancer_id)
