@@ -12,15 +12,13 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from oslo_log import log as logging
+from tempest import config
 import testscenarios
 
-from neutron_lbaas.tests.tempest.lib import config
 from neutron_lbaas.tests.tempest.v2.ddt import base_ddt
 
 CONF = config.CONF
 
-LOG = logging.getLogger(__name__)
 
 """
 Tests the following operations in the Neutron-LBaaS API using the
