@@ -18,8 +18,8 @@ import contextlib
 import socket
 
 import mock
-from neutron.common import exceptions
 from neutron.plugins.common import constants
+from neutron_lib import exceptions
 
 from neutron_lbaas.drivers.haproxy import namespace_driver
 from neutron_lbaas.services.loadbalancer import data_models
@@ -37,14 +37,13 @@ class TestHaproxyNSDriver(base.BaseTestCase):
         conf.haproxy.user_group = 'test_group'
         conf.haproxy.send_gratuitous_arp = 3
         self.conf = conf
-        self.mock_importer = mock.patch.object(namespace_driver,
-                                               'importutils').start()
-
         self.rpc_mock = mock.Mock()
-        self.driver = namespace_driver.HaproxyNSDriver(
-            conf,
-            self.rpc_mock
-        )
+        with mock.patch(
+                'neutron.common.utils.load_class_by_alias_or_classname'):
+            self.driver = namespace_driver.HaproxyNSDriver(
+                conf,
+                self.rpc_mock
+            )
         self.vif_driver = mock.Mock()
         self.driver.vif_driver = self.vif_driver
         self._build_mock_data_models()
@@ -242,7 +241,7 @@ class TestHaproxyNSDriver(base.BaseTestCase):
     def test_update(self):
         self.driver._get_state_file_path = mock.Mock(return_value='/path')
         self.driver._spawn = mock.Mock()
-        with mock.patch('__builtin__.open') as m_open:
+        with mock.patch('six.moves.builtins.open') as m_open:
             file_mock = mock.MagicMock()
             m_open.return_value = file_mock
             file_mock.__enter__.return_value = file_mock
@@ -538,6 +537,7 @@ class BaseTestListenerManager(BaseTestLoadBalancerManager):
         self.listener2 = data_models.Listener(id='listener2')
         self.in_listener.loadbalancer = self.in_lb
         self.listener2.loadbalancer = self.in_lb
+        self.in_lb.listeners = [self.in_listener, self.listener2]
         self.refresh = self.driver.loadbalancer.refresh
 
 
@@ -583,7 +583,9 @@ class BaseTestPoolManager(BaseTestListenerManager):
         super(BaseTestPoolManager, self).setUp()
         self.in_pool = data_models.Pool(id='pool1')
         self.in_listener.default_pool = self.in_pool
-        self.in_pool.listener = self.in_listener
+        self.in_pool.loadbalancer = self.in_lb
+        self.in_pool.listeners = [self.in_listener]
+        self.in_lb.pools = [self.in_pool]
 
 
 class TestPoolManager(BaseTestPoolManager):
@@ -668,7 +670,7 @@ class TestNamespaceDriverModule(base.BaseTestCase):
     @mock.patch('neutron.agent.linux.utils.execute')
     def test_kill_pids_in_file(self, execute, exists):
         pid_path = '/var/lib/data'
-        with mock.patch('__builtin__.open') as m_open:
+        with mock.patch('six.moves.builtins.open') as m_open:
             exists.return_value = False
             file_mock = mock.MagicMock()
             m_open.return_value = file_mock
