@@ -16,7 +16,6 @@
 import mock
 from neutron.api import extensions
 from neutron.api.v2 import attributes
-from neutron.common import constants
 from neutron import context
 from neutron.extensions import agent
 from neutron import manager
@@ -25,6 +24,7 @@ from neutron.tests.common import helpers
 from neutron.tests.unit.api import test_extensions
 from neutron.tests.unit.db import test_agentschedulers_db
 from neutron.tests.unit.extensions import test_agent
+from neutron_lib import constants
 from oslo_config import cfg
 import six
 from webob import exc
@@ -105,8 +105,8 @@ class LBaaSAgentSchedulerTestCase(test_agent.AgentDBTestMixIn,
             lbaas_agent = self._get_lbaas_agent_hosting_pool(
                 pool['pool']['id'])
             self.assertIsNotNone(lbaas_agent)
-            self.assertEqual(lbaas_agent['agent']['agent_type'],
-                             constants.AGENT_TYPE_LOADBALANCER)
+            self.assertEqual(constants.AGENT_TYPE_LOADBALANCER,
+                             lbaas_agent['agent']['agent_type'])
             pools = self._list_pools_hosted_by_lbaas_agent(
                 lbaas_agent['agent']['id'])
             self.assertEqual(1, len(pools['pools']))
@@ -184,8 +184,8 @@ class LBaaSAgentSchedulerTestCase(test_agent.AgentDBTestMixIn,
             lbaas_agent = self._get_lbaas_agent_hosting_pool(
                 pool['pool']['id'])
             self.assertIsNotNone(lbaas_agent)
-            self.assertEqual(lbaas_agent['agent']['agent_type'],
-                             constants.AGENT_TYPE_LOADBALANCER)
+            self.assertEqual(constants.AGENT_TYPE_LOADBALANCER,
+                             lbaas_agent['agent']['agent_type'])
             pools = self._list_pools_hosted_by_lbaas_agent(
                 lbaas_agent['agent']['id'])
             self.assertEqual(1, len(pools['pools']))
@@ -194,7 +194,7 @@ class LBaaSAgentSchedulerTestCase(test_agent.AgentDBTestMixIn,
             req = self.new_delete_request('pools',
                                           pool['pool']['id'])
             res = req.get_response(self.ext_api)
-            self.assertEqual(res.status_int, exc.HTTPNoContent.code)
+            self.assertEqual(exc.HTTPNoContent.code, res.status_int)
             pools = self._list_pools_hosted_by_lbaas_agent(
                 lbaas_agent['agent']['id'])
             self.assertEqual(0, len(pools['pools']))
