@@ -24,6 +24,7 @@ from webob import exc
 
 from neutron_lbaas.extensions import loadbalancer
 from neutron_lbaas.extensions import loadbalancerv2
+from neutron_lbaas.extensions import sharedpools
 from neutron_lbaas.tests import base
 
 
@@ -64,10 +65,10 @@ class LoadBalancerExtensionTestCase(base.ExtensionTestCase):
                             content_type='application/%s' % self.fmt)
         instance.create_vip.assert_called_with(mock.ANY,
                                                vip=data)
-        self.assertEqual(res.status_int, exc.HTTPCreated.code)
+        self.assertEqual(exc.HTTPCreated.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('vip', res)
-        self.assertEqual(res['vip'], return_value)
+        self.assertEqual(return_value, res['vip'])
 
     def test_vip_create_with_connection_limit_smaller_than_min_value(self):
         data = {'vip': {'name': 'vip1',
@@ -101,7 +102,7 @@ class LoadBalancerExtensionTestCase(base.ExtensionTestCase):
 
         instance.get_vips.assert_called_with(mock.ANY, fields=mock.ANY,
                                              filters=mock.ANY)
-        self.assertEqual(res.status_int, exc.HTTPOk.code)
+        self.assertEqual(exc.HTTPOk.code, res.status_int)
 
     def test_vip_update(self):
         vip_id = _uuid()
@@ -120,10 +121,10 @@ class LoadBalancerExtensionTestCase(base.ExtensionTestCase):
 
         instance.update_vip.assert_called_with(mock.ANY, vip_id,
                                                vip=update_data)
-        self.assertEqual(res.status_int, exc.HTTPOk.code)
+        self.assertEqual(exc.HTTPOk.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('vip', res)
-        self.assertEqual(res['vip'], return_value)
+        self.assertEqual(return_value, res['vip'])
 
     def test_vip_update_with_connection_limit_smaller_than_min_value(self):
         vip_id = _uuid()
@@ -149,10 +150,10 @@ class LoadBalancerExtensionTestCase(base.ExtensionTestCase):
 
         instance.get_vip.assert_called_with(mock.ANY, vip_id,
                                             fields=mock.ANY)
-        self.assertEqual(res.status_int, exc.HTTPOk.code)
+        self.assertEqual(exc.HTTPOk.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('vip', res)
-        self.assertEqual(res['vip'], return_value)
+        self.assertEqual(return_value, res['vip'])
 
     def test_vip_delete(self):
         self._test_entity_delete('vip')
@@ -180,10 +181,10 @@ class LoadBalancerExtensionTestCase(base.ExtensionTestCase):
         data['pool']['provider'] = attr.ATTR_NOT_SPECIFIED
         instance.create_pool.assert_called_with(mock.ANY,
                                                 pool=data)
-        self.assertEqual(res.status_int, exc.HTTPCreated.code)
+        self.assertEqual(exc.HTTPCreated.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('pool', res)
-        self.assertEqual(res['pool'], return_value)
+        self.assertEqual(return_value, res['pool'])
 
     def test_pool_list(self):
         pool_id = _uuid()
@@ -199,7 +200,7 @@ class LoadBalancerExtensionTestCase(base.ExtensionTestCase):
 
         instance.get_pools.assert_called_with(mock.ANY, fields=mock.ANY,
                                               filters=mock.ANY)
-        self.assertEqual(res.status_int, exc.HTTPOk.code)
+        self.assertEqual(exc.HTTPOk.code, res.status_int)
 
     def test_pool_update(self):
         pool_id = _uuid()
@@ -218,10 +219,10 @@ class LoadBalancerExtensionTestCase(base.ExtensionTestCase):
 
         instance.update_pool.assert_called_with(mock.ANY, pool_id,
                                                 pool=update_data)
-        self.assertEqual(res.status_int, exc.HTTPOk.code)
+        self.assertEqual(exc.HTTPOk.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('pool', res)
-        self.assertEqual(res['pool'], return_value)
+        self.assertEqual(return_value, res['pool'])
 
     def test_pool_get(self):
         pool_id = _uuid()
@@ -238,10 +239,10 @@ class LoadBalancerExtensionTestCase(base.ExtensionTestCase):
 
         instance.get_pool.assert_called_with(mock.ANY, pool_id,
                                              fields=mock.ANY)
-        self.assertEqual(res.status_int, exc.HTTPOk.code)
+        self.assertEqual(exc.HTTPOk.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('pool', res)
-        self.assertEqual(res['pool'], return_value)
+        self.assertEqual(return_value, res['pool'])
 
     def test_pool_delete(self):
         self._test_entity_delete('pool')
@@ -258,10 +259,10 @@ class LoadBalancerExtensionTestCase(base.ExtensionTestCase):
         res = self.api.get(path)
 
         instance.stats.assert_called_with(mock.ANY, pool_id)
-        self.assertEqual(res.status_int, exc.HTTPOk.code)
+        self.assertEqual(exc.HTTPOk.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('stats', res)
-        self.assertEqual(res['stats'], stats['stats'])
+        self.assertEqual(stats['stats'], res['stats'])
 
     def test_member_create(self):
         member_id = _uuid()
@@ -281,10 +282,10 @@ class LoadBalancerExtensionTestCase(base.ExtensionTestCase):
                             content_type='application/%s' % self.fmt)
         instance.create_member.assert_called_with(mock.ANY,
                                                   member=data)
-        self.assertEqual(res.status_int, exc.HTTPCreated.code)
+        self.assertEqual(exc.HTTPCreated.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('member', res)
-        self.assertEqual(res['member'], return_value)
+        self.assertEqual(return_value, res['member'])
 
     def test_member_list(self):
         member_id = _uuid()
@@ -300,7 +301,7 @@ class LoadBalancerExtensionTestCase(base.ExtensionTestCase):
 
         instance.get_members.assert_called_with(mock.ANY, fields=mock.ANY,
                                                 filters=mock.ANY)
-        self.assertEqual(res.status_int, exc.HTTPOk.code)
+        self.assertEqual(exc.HTTPOk.code, res.status_int)
 
     def test_member_update(self):
         member_id = _uuid()
@@ -319,10 +320,10 @@ class LoadBalancerExtensionTestCase(base.ExtensionTestCase):
 
         instance.update_member.assert_called_with(mock.ANY, member_id,
                                                   member=update_data)
-        self.assertEqual(res.status_int, exc.HTTPOk.code)
+        self.assertEqual(exc.HTTPOk.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('member', res)
-        self.assertEqual(res['member'], return_value)
+        self.assertEqual(return_value, res['member'])
 
     def test_member_get(self):
         member_id = _uuid()
@@ -339,10 +340,10 @@ class LoadBalancerExtensionTestCase(base.ExtensionTestCase):
 
         instance.get_member.assert_called_with(mock.ANY, member_id,
                                                fields=mock.ANY)
-        self.assertEqual(res.status_int, exc.HTTPOk.code)
+        self.assertEqual(exc.HTTPOk.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('member', res)
-        self.assertEqual(res['member'], return_value)
+        self.assertEqual(return_value, res['member'])
 
     def test_member_delete(self):
         self._test_entity_delete('member')
@@ -369,10 +370,10 @@ class LoadBalancerExtensionTestCase(base.ExtensionTestCase):
                             content_type='application/%s' % self.fmt)
         instance.create_health_monitor.assert_called_with(mock.ANY,
                                                           health_monitor=data)
-        self.assertEqual(res.status_int, exc.HTTPCreated.code)
+        self.assertEqual(exc.HTTPCreated.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('health_monitor', res)
-        self.assertEqual(res['health_monitor'], return_value)
+        self.assertEqual(return_value, res['health_monitor'])
 
     def test_health_monitor_create_with_timeout_negative(self):
         data = {'health_monitor': {'type': 'HTTP',
@@ -405,7 +406,7 @@ class LoadBalancerExtensionTestCase(base.ExtensionTestCase):
 
         instance.get_health_monitors.assert_called_with(
             mock.ANY, fields=mock.ANY, filters=mock.ANY)
-        self.assertEqual(res.status_int, exc.HTTPOk.code)
+        self.assertEqual(exc.HTTPOk.code, res.status_int)
 
     def test_health_monitor_update(self):
         health_monitor_id = _uuid()
@@ -426,10 +427,10 @@ class LoadBalancerExtensionTestCase(base.ExtensionTestCase):
 
         instance.update_health_monitor.assert_called_with(
             mock.ANY, health_monitor_id, health_monitor=update_data)
-        self.assertEqual(res.status_int, exc.HTTPOk.code)
+        self.assertEqual(exc.HTTPOk.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('health_monitor', res)
-        self.assertEqual(res['health_monitor'], return_value)
+        self.assertEqual(return_value, res['health_monitor'])
 
     def test_health_monitor_get(self):
         health_monitor_id = _uuid()
@@ -448,10 +449,10 @@ class LoadBalancerExtensionTestCase(base.ExtensionTestCase):
 
         instance.get_health_monitor.assert_called_with(
             mock.ANY, health_monitor_id, fields=mock.ANY)
-        self.assertEqual(res.status_int, exc.HTTPOk.code)
+        self.assertEqual(exc.HTTPOk.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('health_monitor', res)
-        self.assertEqual(res['health_monitor'], return_value)
+        self.assertEqual(return_value, res['health_monitor'])
 
     def test_health_monitor_delete(self):
         self._test_entity_delete('health_monitor')
@@ -469,10 +470,10 @@ class LoadBalancerExtensionTestCase(base.ExtensionTestCase):
                             content_type='application/%s' % self.fmt)
         instance.create_pool_health_monitor.assert_called_with(
             mock.ANY, pool_id='id1', health_monitor=data)
-        self.assertEqual(res.status_int, exc.HTTPCreated.code)
+        self.assertEqual(exc.HTTPCreated.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('health_monitor', res)
-        self.assertEqual(res['health_monitor'], return_value)
+        self.assertEqual(return_value, res['health_monitor'])
 
     def test_delete_pool_health_monitor(self):
         health_monitor_id = _uuid()
@@ -483,7 +484,7 @@ class LoadBalancerExtensionTestCase(base.ExtensionTestCase):
         instance = self.plugin.return_value
         instance.delete_pool_health_monitor.assert_called_with(
             mock.ANY, health_monitor_id, pool_id='id1')
-        self.assertEqual(res.status_int, exc.HTTPNoContent.code)
+        self.assertEqual(exc.HTTPNoContent.code, res.status_int)
 
 
 class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
@@ -491,9 +492,12 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
 
     def setUp(self):
         super(LoadBalancerExtensionV2TestCase, self).setUp()
+        resource_map = loadbalancerv2.RESOURCE_ATTRIBUTE_MAP.copy()
+        for k in sharedpools.EXTENDED_ATTRIBUTES_2_0.keys():
+            resource_map[k].update(sharedpools.EXTENDED_ATTRIBUTES_2_0[k])
         self._setUpExtension(
             'neutron_lbaas.extensions.loadbalancerv2.LoadBalancerPluginBaseV2',
-            constants.LOADBALANCERV2, loadbalancerv2.RESOURCE_ATTRIBUTE_MAP,
+            constants.LOADBALANCERV2, resource_map,
             loadbalancerv2.Loadbalancerv2, 'lbaas', use_quota=True)
 
     def test_loadbalancer_create(self):
@@ -513,14 +517,43 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
         res = self.api.post(_get_path('lbaas/loadbalancers', fmt=self.fmt),
                             self.serialize(data),
                             content_type='application/{0}'.format(self.fmt))
-        data['loadbalancer'].update({'provider': attr.ATTR_NOT_SPECIFIED})
+        data['loadbalancer'].update({'provider': attr.ATTR_NOT_SPECIFIED,
+                                     'flavor_id': attr.ATTR_NOT_SPECIFIED})
         instance.create_loadbalancer.assert_called_with(mock.ANY,
                                                         loadbalancer=data)
 
-        self.assertEqual(res.status_int, exc.HTTPCreated.code)
+        self.assertEqual(exc.HTTPCreated.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('loadbalancer', res)
-        self.assertEqual(res['loadbalancer'], return_value)
+        self.assertEqual(return_value, res['loadbalancer'])
+
+    def test_loadbalancer_create_invalid_flavor(self):
+        data = {'loadbalancer': {'name': 'lb1',
+                                 'description': 'descr_lb1',
+                                 'tenant_id': _uuid(),
+                                 'vip_subnet_id': _uuid(),
+                                 'admin_state_up': True,
+                                 'flavor_id': 123,
+                                 'vip_address': '127.0.0.1'}}
+        res = self.api.post(_get_path('lbaas/loadbalancers', fmt=self.fmt),
+                            self.serialize(data),
+                            content_type='application/{0}'.format(self.fmt),
+                            expect_errors=True)
+        self.assertEqual(400, res.status_int)
+
+    def test_loadbalancer_create_valid_flavor(self):
+        data = {'loadbalancer': {'name': 'lb1',
+                                 'description': 'descr_lb1',
+                                 'tenant_id': _uuid(),
+                                 'vip_subnet_id': _uuid(),
+                                 'admin_state_up': True,
+                                 'flavor_id': _uuid(),
+                                 'vip_address': '127.0.0.1'}}
+        res = self.api.post(_get_path('lbaas/loadbalancers', fmt=self.fmt),
+                            self.serialize(data),
+                            content_type='application/{0}'.format(self.fmt),
+                            expect_errors=True)
+        self.assertEqual(201, res.status_int)
 
     def test_loadbalancer_list(self):
         lb_id = _uuid()
@@ -537,7 +570,7 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
         instance.get_loadbalancers.assert_called_with(mock.ANY,
                                                       fields=mock.ANY,
                                                       filters=mock.ANY)
-        self.assertEqual(res.status_int, exc.HTTPOk.code)
+        self.assertEqual(exc.HTTPOk.code, res.status_int)
 
     def test_loadbalancer_update(self):
         lb_id = _uuid()
@@ -557,10 +590,10 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
 
         instance.update_loadbalancer.assert_called_with(
             mock.ANY, lb_id, loadbalancer=update_data)
-        self.assertEqual(res.status_int, exc.HTTPOk.code)
+        self.assertEqual(exc.HTTPOk.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('loadbalancer', res)
-        self.assertEqual(res['loadbalancer'], return_value)
+        self.assertEqual(return_value, res['loadbalancer'])
 
     def test_loadbalancer_get(self):
         lb_id = _uuid()
@@ -578,10 +611,10 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
 
         instance.get_loadbalancer.assert_called_with(mock.ANY, lb_id,
                                                      fields=mock.ANY)
-        self.assertEqual(res.status_int, exc.HTTPOk.code)
+        self.assertEqual(exc.HTTPOk.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('loadbalancer', res)
-        self.assertEqual(res['loadbalancer'], return_value)
+        self.assertEqual(return_value, res['loadbalancer'])
 
     def test_loadbalancer_delete(self):
         self._test_entity_delete('loadbalancer')
@@ -593,6 +626,7 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
                              'description': 'listen-1-desc',
                              'protocol': 'HTTP',
                              'protocol_port': 80,
+                             'default_pool_id': None,
                              'default_tls_container_ref': None,
                              'sni_container_refs': [],
                              'connection_limit': 100,
@@ -611,10 +645,10 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
         instance.create_listener.assert_called_with(mock.ANY,
                                                     listener=data)
 
-        self.assertEqual(res.status_int, exc.HTTPCreated.code)
+        self.assertEqual(exc.HTTPCreated.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('listener', res)
-        self.assertEqual(res['listener'], return_value)
+        self.assertEqual(return_value, res['listener'])
 
     def test_listener_create_with_tls(self):
         listener_id = _uuid()
@@ -626,6 +660,7 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
                              'description': 'listen-1-desc',
                              'protocol': 'HTTP',
                              'protocol_port': 80,
+                             'default_pool_id': None,
                              'default_tls_container_ref': tls_ref,
                              'sni_container_refs': sni_refs,
                              'connection_limit': 100,
@@ -681,7 +716,7 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
         instance.get_listeners.assert_called_with(mock.ANY,
                                                   fields=mock.ANY,
                                                   filters=mock.ANY)
-        self.assertEqual(res.status_int, exc.HTTPOk.code)
+        self.assertEqual(exc.HTTPOk.code, res.status_int)
 
     def test_listener_update(self):
         listener_id = _uuid()
@@ -701,10 +736,10 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
 
         instance.update_listener.assert_called_with(
             mock.ANY, listener_id, listener=update_data)
-        self.assertEqual(res.status_int, exc.HTTPOk.code)
+        self.assertEqual(exc.HTTPOk.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('listener', res)
-        self.assertEqual(res['listener'], return_value)
+        self.assertEqual(return_value, res['listener'])
 
     def test_listener_update_with_tls(self):
         listener_id = _uuid()
@@ -760,10 +795,10 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
 
         instance.get_listener.assert_called_with(mock.ANY, listener_id,
                                                  fields=mock.ANY)
-        self.assertEqual(res.status_int, exc.HTTPOk.code)
+        self.assertEqual(exc.HTTPOk.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('listener', res)
-        self.assertEqual(res['listener'], return_value)
+        self.assertEqual(return_value, res['listener'])
 
     def test_listener_delete(self):
         self._test_entity_delete('listener')
@@ -775,12 +810,13 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
                          'protocol': 'HTTP',
                          'lb_algorithm': 'ROUND_ROBIN',
                          'admin_state_up': True,
+                         'loadbalancer_id': _uuid(),
+                         'listener_id': None,
                          'tenant_id': _uuid(),
-                         'listener_id': _uuid(),
                          'session_persistence': {}}}
         return_value = copy.copy(data['pool'])
         return_value.update({'id': pool_id})
-        del return_value['listener_id']
+        return_value.pop('listener_id')
 
         instance = self.plugin.return_value
         instance.create_pool.return_value = return_value
@@ -788,10 +824,10 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
                             self.serialize(data),
                             content_type='application/%s' % self.fmt)
         instance.create_pool.assert_called_with(mock.ANY, pool=data)
-        self.assertEqual(res.status_int, exc.HTTPCreated.code)
+        self.assertEqual(exc.HTTPCreated.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('pool', res)
-        self.assertEqual(res['pool'], return_value)
+        self.assertEqual(return_value, res['pool'])
 
     def test_pool_list(self):
         pool_id = _uuid()
@@ -807,7 +843,7 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
 
         instance.get_pools.assert_called_with(mock.ANY, fields=mock.ANY,
                                               filters=mock.ANY)
-        self.assertEqual(res.status_int, exc.HTTPOk.code)
+        self.assertEqual(exc.HTTPOk.code, res.status_int)
 
     def test_pool_update(self):
         pool_id = _uuid()
@@ -826,10 +862,10 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
 
         instance.update_pool.assert_called_with(mock.ANY, pool_id,
                                                 pool=update_data)
-        self.assertEqual(res.status_int, exc.HTTPOk.code)
+        self.assertEqual(exc.HTTPOk.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('pool', res)
-        self.assertEqual(res['pool'], return_value)
+        self.assertEqual(return_value, res['pool'])
 
     def test_pool_get(self):
         pool_id = _uuid()
@@ -846,10 +882,10 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
 
         instance.get_pool.assert_called_with(mock.ANY, pool_id,
                                              fields=mock.ANY)
-        self.assertEqual(res.status_int, exc.HTTPOk.code)
+        self.assertEqual(exc.HTTPOk.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('pool', res)
-        self.assertEqual(res['pool'], return_value)
+        self.assertEqual(return_value, res['pool'])
 
     def test_pool_delete(self):
         self._test_entity_delete('pool')
@@ -862,7 +898,8 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
                            'weight': 1,
                            'subnet_id': subnet_id,
                            'admin_state_up': True,
-                           'tenant_id': _uuid()}}
+                           'tenant_id': _uuid(),
+                           'name': 'member1'}}
         return_value = copy.copy(data['member'])
         return_value.update({'id': member_id})
 
@@ -876,17 +913,18 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
         instance.create_pool_member.assert_called_with(mock.ANY,
                                                        pool_id='pid1',
                                                        member=data)
-        self.assertEqual(res.status_int, exc.HTTPCreated.code)
+        self.assertEqual(exc.HTTPCreated.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('member', res)
-        self.assertEqual(res['member'], return_value)
+        self.assertEqual(return_value, res['member'])
 
     def test_pool_member_list(self):
         member_id = _uuid()
         return_value = [{'name': 'member1',
                          'admin_state_up': True,
                          'tenant_id': _uuid(),
-                         'id': member_id}]
+                         'id': member_id,
+                         'name': 'member1'}]
 
         instance = self.plugin.return_value
         instance.get_pools.return_value = return_value
@@ -898,14 +936,15 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
                                                      fields=mock.ANY,
                                                      filters=mock.ANY,
                                                      pool_id='pid1')
-        self.assertEqual(res.status_int, exc.HTTPOk.code)
+        self.assertEqual(exc.HTTPOk.code, res.status_int)
 
     def test_pool_member_update(self):
         member_id = _uuid()
         update_data = {'member': {'admin_state_up': False}}
         return_value = {'admin_state_up': False,
                         'tenant_id': _uuid(),
-                        'id': member_id}
+                        'id': member_id,
+                        'name': 'member1'}
 
         instance = self.plugin.return_value
         instance.update_pool_member.return_value = return_value
@@ -918,16 +957,17 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
         instance.update_pool_member.assert_called_with(
             mock.ANY, member_id, pool_id='pid1',
             member=update_data)
-        self.assertEqual(res.status_int, exc.HTTPOk.code)
+        self.assertEqual(exc.HTTPOk.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('member', res)
-        self.assertEqual(res['member'], return_value)
+        self.assertEqual(return_value, res['member'])
 
     def test_pool_member_get(self):
         member_id = _uuid()
         return_value = {'admin_state_up': False,
                         'tenant_id': _uuid(),
-                        'id': member_id}
+                        'id': member_id,
+                        'name': 'member1'}
 
         instance = self.plugin.return_value
         instance.get_pool_member.return_value = return_value
@@ -939,10 +979,10 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
                                                     member_id,
                                                     fields=mock.ANY,
                                                     pool_id='pid1')
-        self.assertEqual(res.status_int, exc.HTTPOk.code)
+        self.assertEqual(exc.HTTPOk.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('member', res)
-        self.assertEqual(res['member'], return_value)
+        self.assertEqual(return_value, res['member'])
 
     def test_pool_member_delete(self):
         entity_id = _uuid()
@@ -953,7 +993,7 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
                                 "delete_pool_member")
         delete_entity.assert_called_with(mock.ANY, entity_id,
                                          pool_id='pid1')
-        self.assertEqual(res.status_int, exc.HTTPNoContent.code)
+        self.assertEqual(exc.HTTPNoContent.code, res.status_int)
 
     def test_health_monitor_create(self):
         health_monitor_id = _uuid()
@@ -966,7 +1006,8 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
                                   'expected_codes': '200-300',
                                   'admin_state_up': True,
                                   'tenant_id': _uuid(),
-                                  'pool_id': _uuid()}}
+                                  'pool_id': _uuid(),
+                                  'name': 'monitor1'}}
         return_value = copy.copy(data['healthmonitor'])
         return_value.update({'id': health_monitor_id})
         del return_value['pool_id']
@@ -979,10 +1020,10 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
                             content_type='application/%s' % self.fmt)
         instance.create_healthmonitor.assert_called_with(
             mock.ANY, healthmonitor=data)
-        self.assertEqual(res.status_int, exc.HTTPCreated.code)
+        self.assertEqual(exc.HTTPCreated.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('healthmonitor', res)
-        self.assertEqual(res['healthmonitor'], return_value)
+        self.assertEqual(return_value, res['healthmonitor'])
 
     def test_health_monitor_create_with_timeout_negative(self):
         data = {'healthmonitor': {'type': 'HTTP',
@@ -994,7 +1035,8 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
                                   'expected_codes': '200-300',
                                   'admin_state_up': True,
                                   'tenant_id': _uuid(),
-                                  'pool_id': _uuid()}}
+                                  'pool_id': _uuid(),
+                                  'name': 'monitor1'}}
         res = self.api.post(_get_path('lbaas/healthmonitors',
                                       fmt=self.fmt),
                             self.serialize(data),
@@ -1007,7 +1049,8 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
         return_value = [{'type': 'HTTP',
                          'admin_state_up': True,
                          'tenant_id': _uuid(),
-                         'id': health_monitor_id}]
+                         'id': health_monitor_id,
+                         'name': 'monitor1'}]
 
         instance = self.plugin.return_value
         instance.get_healthmonitors.return_value = return_value
@@ -1016,7 +1059,7 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
 
         instance.get_healthmonitors.assert_called_with(
             mock.ANY, fields=mock.ANY, filters=mock.ANY)
-        self.assertEqual(res.status_int, exc.HTTPOk.code)
+        self.assertEqual(exc.HTTPOk.code, res.status_int)
 
     def test_health_monitor_update(self):
         health_monitor_id = _uuid()
@@ -1024,7 +1067,8 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
         return_value = {'type': 'HTTP',
                         'admin_state_up': False,
                         'tenant_id': _uuid(),
-                        'id': health_monitor_id}
+                        'id': health_monitor_id,
+                        'name': 'monitor1'}
 
         instance = self.plugin.return_value
         instance.update_healthmonitor.return_value = return_value
@@ -1036,17 +1080,18 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
 
         instance.update_healthmonitor.assert_called_with(
             mock.ANY, health_monitor_id, healthmonitor=update_data)
-        self.assertEqual(res.status_int, exc.HTTPOk.code)
+        self.assertEqual(exc.HTTPOk.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('healthmonitor', res)
-        self.assertEqual(res['healthmonitor'], return_value)
+        self.assertEqual(return_value, res['healthmonitor'])
 
     def test_health_monitor_get(self):
         health_monitor_id = _uuid()
         return_value = {'type': 'HTTP',
                         'admin_state_up': False,
                         'tenant_id': _uuid(),
-                        'id': health_monitor_id}
+                        'id': health_monitor_id,
+                        'name': 'monitor1'}
 
         instance = self.plugin.return_value
         instance.get_healthmonitor.return_value = return_value
@@ -1057,10 +1102,10 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
 
         instance.get_healthmonitor.assert_called_with(
             mock.ANY, health_monitor_id, fields=mock.ANY)
-        self.assertEqual(res.status_int, exc.HTTPOk.code)
+        self.assertEqual(exc.HTTPOk.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('healthmonitor', res)
-        self.assertEqual(res['healthmonitor'], return_value)
+        self.assertEqual(return_value, res['healthmonitor'])
 
     def test_health_monitor_delete(self):
         entity_id = _uuid()
@@ -1070,7 +1115,7 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
         delete_entity = getattr(self.plugin.return_value,
                                 "delete_healthmonitor")
         delete_entity.assert_called_with(mock.ANY, entity_id)
-        self.assertEqual(res.status_int, exc.HTTPNoContent.code)
+        self.assertEqual(exc.HTTPNoContent.code, res.status_int)
 
     def test_load_balancer_stats(self):
         load_balancer_id = _uuid()
@@ -1084,10 +1129,10 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
         res = self.api.get(path)
 
         instance.stats.assert_called_with(mock.ANY, load_balancer_id)
-        self.assertEqual(res.status_int, exc.HTTPOk.code)
+        self.assertEqual(exc.HTTPOk.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('stats', res)
-        self.assertEqual(res['stats'], stats['stats'])
+        self.assertEqual(stats['stats'], res['stats'])
 
     def test_load_balancer_statuses(self):
         load_balancer_id = _uuid()
@@ -1099,7 +1144,7 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
                          action="statuses", fmt=self.fmt)
         res = self.api.get(path)
         instance.statuses.assert_called_with(mock.ANY, load_balancer_id)
-        self.assertEqual(res.status_int, exc.HTTPOk.code)
+        self.assertEqual(exc.HTTPOk.code, res.status_int)
         res = self.deserialize(res)
         self.assertIn('statuses', res)
-        self.assertEqual(res['statuses'], statuses['statuses'])
+        self.assertEqual(statuses['statuses'], res['statuses'])
